@@ -18,6 +18,7 @@ from typing import Optional
 import numpy as np
 from pydub import AudioSegment
 from openai import AsyncOpenAI
+from .provider_discovery import is_local_provider
 import httpx
 
 from .config import SAMPLE_RATE
@@ -134,17 +135,27 @@ def get_openai_clients(api_key: str, stt_base_url: Optional[str] = None, tts_bas
         'timeout': httpx.Timeout(30.0, connect=5.0),
         'limits': httpx.Limits(max_keepalive_connections=5, max_connections=10),
     }
-    
+
+    # Disable retries for local endpoints - they either work or don't
+    stt_max_retries = 0 if is_local_provider(stt_base_url) else 2
+    tts_max_retries = 0 if is_local_provider(tts_base_url) else 2
+
+    # Create HTTP clients
+    stt_http_client = httpx.AsyncClient(**http_client_config)
+    tts_http_client = httpx.AsyncClient(**http_client_config)
+
     return {
         'stt': AsyncOpenAI(
             api_key=api_key,
             base_url=stt_base_url,
-            http_client=httpx.AsyncClient(**http_client_config)
+            http_client=stt_http_client,
+            max_retries=stt_max_retries
         ),
         'tts': AsyncOpenAI(
             api_key=api_key,
             base_url=tts_base_url,
-            http_client=httpx.AsyncClient(**http_client_config)
+            http_client=tts_http_client,
+            max_retries=tts_max_retries
         )
     }
 
@@ -394,10 +405,10 @@ async def text_to_speech(
                         # Log TTS playback start event
                         if event_logger:
                             event_logger.log_event(event_logger.TTS_PLAYBACK_START)
-                        
+
                         # Add configurable silence at the beginning to prevent clipping
-                        from .config import PIP_LEADING_SILENCE
-                        silence_duration = PIP_LEADING_SILENCE  # seconds
+                        from .config import CHIME_LEADING_SILENCE
+                        silence_duration = CHIME_LEADING_SILENCE  # seconds
                         silence_samples = int(audio.frame_rate * silence_duration)
                         # Match the shape of the samples array exactly
                         if samples.ndim == 1:
@@ -488,13 +499,13 @@ async def text_to_speech(
         logger.error(f"TTS failed: {e}")
         logger.error(f"TTS config when error occurred - Model: {tts_model}, Voice: {tts_voice}, Base URL: {tts_base_url}")
         logger.debug(f"Full TTS error details:", exc_info=True)
-        
+
         # Check for authentication errors
         error_message = str(e).lower()
         if hasattr(e, 'response'):
             logger.error(f"HTTP status: {e.response.status_code if hasattr(e.response, 'status_code') else 'unknown'}")
             logger.error(f"Response text: {e.response.text if hasattr(e.response, 'text') else 'unknown'}")
-            
+
             # Check for 401 Unauthorized specifically on OpenAI endpoints
             if hasattr(e.response, 'status_code') and e.response.status_code == 401:
                 if 'openai.com' in tts_base_url:
@@ -504,7 +515,13 @@ async def text_to_speech(
             if 'openai.com' in tts_base_url:
                 logger.error("⚠️  Authentication issue detected. Please check your OPENAI_API_KEY.")
                 logger.error("   For local-only usage, ensure Kokoro is running and configured.")
-        
+
+        # Re-raise API errors so simple_tts_failover can parse them properly
+        # This allows proper error messages to be shown to users
+        # We'll only return False for local playback errors
+        if hasattr(e, 'response') or 'Error code:' in str(e) or isinstance(e, Exception) and not error_message.startswith('error playing audio'):
+            raise
+
         return False, metrics
 
 
@@ -568,11 +585,11 @@ def generate_chime(
     chime = np.concatenate(all_samples)
     
     # Import config values if not overridden
-    from .config import PIP_LEADING_SILENCE, PIP_TRAILING_SILENCE
-    
+    from .config import CHIME_LEADING_SILENCE, CHIME_TRAILING_SILENCE
+
     # Use parameter overrides or fall back to config
-    actual_leading_silence = leading_silence if leading_silence is not None else PIP_LEADING_SILENCE
-    actual_trailing_silence = trailing_silence if trailing_silence is not None else PIP_TRAILING_SILENCE
+    actual_leading_silence = leading_silence if leading_silence is not None else CHIME_LEADING_SILENCE
+    actual_trailing_silence = trailing_silence if trailing_silence is not None else CHIME_TRAILING_SILENCE
     
     # Add leading silence for Bluetooth wake-up time
     # This prevents the beginning of the chime from being cut off
